==> one_target_mobile_sdk-0.0.2.tar.gz: lib/src/analytics.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'common/const.dart';

class Analytics {
  static const MethodChannel _channel = MethodChannel(Const.sdk);

  static void _log(String msg) {
    if (kDebugMode) {
      print(msg);
    }
  }

  static Future<String?> get platformVersion async {
    final String? version =
        await _channel.invokeMethod(Const.getPlatformVersion);
    return version;
  }

  static Future<bool> setupTracking(bool isEnvironmentDev, String? writeKey,
      {bool isShowLog = false}) async {
    return await _channel.invokeMethod(
      Const.setupTracking,
      {
        "isEnvironmentDev": isEnvironmentDev,
        "writeKey": writeKey,
        "isShowLog": isShowLog,
      },
    );
  }

  static void trackEvent(String? workSpaceId, Map? identityId,
      String? eventName, int? eventDate, Map? eventData,
      {Function(Object?, bool?, int?, Object?)? onResponse,
      Function(Object?, String?)? onFailure}) async {
    // print("workSpaceId $workSpaceId");
    // print("identityId $identityId");
    // print("eventName $eventName");
    // print("eventDate $eventDate");
    // print("eventData $eventData");
    final result = await _channel.invokeMethod<Map<dynamic, dynamic>>(
      Const.trackEvent,
      {
        "workSpaceId": workSpaceId,
        "identityId": identityId,
        "eventName": eventName,
        "eventDate": eventDate,
        "eventData": eventData,
      },
    );
    if (result != null) {
      final input = result['input'] as Object?;
      // _log("~~~~~~~~~~~~~monitorEvent: ${jsonEncode(monitorEvent)}");
      final isSuccessful = result['isSuccessful'] as bool?;
      final code = result['code'] as int?;
      final response = result['response'] as Object?;
      // _log("~~~~~~~~~~~~~isSuccessful: $isSuccessful");
      // _log("~~~~~~~~~~~~~code: $code");
      // _log("~~~~~~~~~~~~~response: ${jsonEncode(response)}");
      if (isSuccessful != null && code != null) {
        onResponse?.call(input, isSuccessful, code, response);
      }
      final error = result['error'] as String?;
      if (error != null) {
        onFailure?.call(input, error);
      }
    }
  }
}

==> one_target_mobile_sdk-0.0.5.tar.gz: lib/src/analytics.dart <==
import 'dart:async';

import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'common/const.dart';

class Analytics {
  static const MethodChannel _channel = MethodChannel(Const.sdk);

  static void _log(String msg) {
    if (kDebugMode) {
      print(msg);
    }
  }

  static Future<String?> get platformVersion async {
    final String? version =
        await _channel.invokeMethod(Const.getPlatformVersion);
    return version;
  }

  static Future<bool> setupTracking(bool isEnvironmentDev, String? writeKey,
      {bool isShowLog = false}) async {
    return await _channel.invokeMethod(
      Const.setupTracking,
      {
        "isEnvironmentDev": isEnvironmentDev,
        "writeKey": writeKey,
        "isShowLog": isShowLog,
      },
    );
  }

  static void trackEvent(String? workSpaceId, Map? identityId,
      String? eventName, int? eventDate, Map? eventData,
      {Function(Object?)? onResponse, Function(Object?)? onFailure}) async {
    // print("workSpaceId $workSpaceId");
    // print("identityId $identityId");
    // print("eventName $eventName");
    // print("eventDate $eventDate");
    // print("eventData $eventData");
    final result = await _channel.invokeMethod<Map<dynamic, dynamic>>(
      Const.trackEvent,
      {
        "workSpaceId": workSpaceId,
        "identityId": identityId,
        "eventName": eventName,
        "eventDate": eventDate,
        "eventData": eventData,
      },
    );
    if (result != null) {
      final input = result['input'] as Object?;
      // _log("~~~~~~~~~~~~~monitorEvent: ${jsonEncode(monitorEvent)}");
      final isSuccessful = result['isSuccessful'] as bool?;
      final code = result['code'] as int?;
      final response = result['response'] as Object?;
      // _log("~~~~~~~~~~~~~isSuccessful: $isSuccessful");
      // _log("~~~~~~~~~~~~~code: $code");
      // _log("~~~~~~~~~~~~~response: ${jsonEncode(response)}");
      if (response != null) {
        onResponse?.call({
          if (input != null) "input": input,
          if (isSuccessful != null) "isSuccessful": isSuccessful,
          if (code != null) "code": code,
          "response": response,
        });
      }
      final error = result['error'] as String?;
      if (error != null) {
        onFailure?.call({
          if (input != null) "input": input,
          "error": error,
        });
      }
    }
  }
}
